"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import th2_grpc_common.common_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CheckpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    description: typing.Text
    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...
    def __init__(self,
        *,
        description: typing.Text = ...,
        parent_event_id: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["parent_event_id",b"parent_event_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description",b"description","parent_event_id",b"parent_event_id"]) -> None: ...
global___CheckpointRequest = CheckpointRequest

class CheckpointResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CHECKPOINT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint: ...
    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...
    def __init__(self,
        *,
        checkpoint: typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        status: typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["checkpoint",b"checkpoint","status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["checkpoint",b"checkpoint","status",b"status"]) -> None: ...
global___CheckpointResponse = CheckpointResponse

class ChainID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    id: typing.Text
    def __init__(self,
        *,
        id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id"]) -> None: ...
global___ChainID = ChainID

class CheckRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONNECTIVITY_ID_FIELD_NUMBER: builtins.int
    ROOT_FILTER_FIELD_NUMBER: builtins.int
    CHECKPOINT_FIELD_NUMBER: builtins.int
    MESSAGE_TIMEOUT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    BOOK_NAME_FIELD_NUMBER: builtins.int
    @property
    def connectivity_id(self) -> th2_grpc_common.common_pb2.ConnectionID: ...
    @property
    def root_filter(self) -> th2_grpc_common.common_pb2.RootMessageFilter: ...
    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint:
        """Registered Checkpoint. If the chain_id is also set in the request the checkpoint will be ignored"""
        pass
    message_timeout: builtins.int
    """Timeout to wait for messages after checkpoint. The message's timestamp will be used to compute the timeout"""

    timeout: builtins.int
    """Timeout for rule execution. Uses the real time to limit the execution of the rule"""

    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...
    description: typing.Text
    direction: th2_grpc_common.common_pb2.Direction.ValueType
    @property
    def chain_id(self) -> global___ChainID:
        """The chain id to continue checking."""
        pass
    book_name: typing.Text
    """If it's not set the check will be started from the specified checkpoint otherwise checkpoint will be ignored"""

    def __init__(self,
        *,
        connectivity_id: typing.Optional[th2_grpc_common.common_pb2.ConnectionID] = ...,
        root_filter: typing.Optional[th2_grpc_common.common_pb2.RootMessageFilter] = ...,
        checkpoint: typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        message_timeout: builtins.int = ...,
        timeout: builtins.int = ...,
        parent_event_id: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        description: typing.Text = ...,
        direction: th2_grpc_common.common_pb2.Direction.ValueType = ...,
        chain_id: typing.Optional[global___ChainID] = ...,
        book_name: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","checkpoint",b"checkpoint","connectivity_id",b"connectivity_id","parent_event_id",b"parent_event_id","root_filter",b"root_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_name",b"book_name","chain_id",b"chain_id","checkpoint",b"checkpoint","connectivity_id",b"connectivity_id","description",b"description","direction",b"direction","message_timeout",b"message_timeout","parent_event_id",b"parent_event_id","root_filter",b"root_filter","timeout",b"timeout"]) -> None: ...
global___CheckRuleRequest = CheckRuleRequest

class CheckRuleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...
    @property
    def chain_id(self) -> global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""
        pass
    def __init__(self,
        *,
        status: typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        chain_id: typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","status",b"status"]) -> None: ...
global___CheckRuleResponse = CheckRuleResponse

class CheckSequenceRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRE_FILTER_FIELD_NUMBER: builtins.int
    ROOT_MESSAGE_FILTERS_FIELD_NUMBER: builtins.int
    CHECKPOINT_FIELD_NUMBER: builtins.int
    MESSAGE_TIMEOUT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    CONNECTIVITY_ID_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    CHECK_ORDER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    SILENCE_CHECK_FIELD_NUMBER: builtins.int
    BOOK_NAME_FIELD_NUMBER: builtins.int
    @property
    def pre_filter(self) -> global___PreFilter: ...
    @property
    def root_message_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_common.common_pb2.RootMessageFilter]:
        """
        Either this field or message_filters must be set. If both are set the error response will be received from check1
        """
        pass
    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint:
        """Registered Checkpoint. If the chain_id is also set in the request the checkpoint will be ignored"""
        pass
    message_timeout: builtins.int
    """Timeout to wait for messages after checkpoint. The message's timestamp will be used to compute the timeout"""

    timeout: builtins.int
    """Timeout for rule execution. Uses the real time to limit the execution of the rule"""

    @property
    def connectivity_id(self) -> th2_grpc_common.common_pb2.ConnectionID: ...
    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...
    check_order: builtins.bool
    description: typing.Text
    direction: th2_grpc_common.common_pb2.Direction.ValueType
    @property
    def chain_id(self) -> global___ChainID:
        """The chain id to continue checking."""
        pass
    @property
    def silence_check(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """If it's not set the check will be started from the specified checkpoint otherwise checkpoint will be ignored"""
        pass
    book_name: typing.Text
    def __init__(self,
        *,
        pre_filter: typing.Optional[global___PreFilter] = ...,
        root_message_filters: typing.Optional[typing.Iterable[th2_grpc_common.common_pb2.RootMessageFilter]] = ...,
        checkpoint: typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        message_timeout: builtins.int = ...,
        timeout: builtins.int = ...,
        connectivity_id: typing.Optional[th2_grpc_common.common_pb2.ConnectionID] = ...,
        parent_event_id: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        check_order: builtins.bool = ...,
        description: typing.Text = ...,
        direction: th2_grpc_common.common_pb2.Direction.ValueType = ...,
        chain_id: typing.Optional[global___ChainID] = ...,
        silence_check: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        book_name: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","checkpoint",b"checkpoint","connectivity_id",b"connectivity_id","parent_event_id",b"parent_event_id","pre_filter",b"pre_filter","silence_check",b"silence_check"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_name",b"book_name","chain_id",b"chain_id","check_order",b"check_order","checkpoint",b"checkpoint","connectivity_id",b"connectivity_id","description",b"description","direction",b"direction","message_timeout",b"message_timeout","parent_event_id",b"parent_event_id","pre_filter",b"pre_filter","root_message_filters",b"root_message_filters","silence_check",b"silence_check","timeout",b"timeout"]) -> None: ...
global___CheckSequenceRuleRequest = CheckSequenceRuleRequest

class CheckSequenceRuleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...
    @property
    def chain_id(self) -> global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""
        pass
    def __init__(self,
        *,
        status: typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        chain_id: typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","status",b"status"]) -> None: ...
global___CheckSequenceRuleResponse = CheckSequenceRuleResponse

class PreFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class FieldsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> th2_grpc_common.common_pb2.ValueFilter: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[th2_grpc_common.common_pb2.ValueFilter] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    FIELDS_FIELD_NUMBER: builtins.int
    METADATA_FILTER_FIELD_NUMBER: builtins.int
    @property
    def fields(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, th2_grpc_common.common_pb2.ValueFilter]: ...
    @property
    def metadata_filter(self) -> th2_grpc_common.common_pb2.MetadataFilter: ...
    def __init__(self,
        *,
        fields: typing.Optional[typing.Mapping[typing.Text, th2_grpc_common.common_pb2.ValueFilter]] = ...,
        metadata_filter: typing.Optional[th2_grpc_common.common_pb2.MetadataFilter] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata_filter",b"metadata_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fields",b"fields","metadata_filter",b"metadata_filter"]) -> None: ...
global___PreFilter = PreFilter

class NoMessageCheckRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRE_FILTER_FIELD_NUMBER: builtins.int
    MESSAGE_TIMEOUT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    CHECKPOINT_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    CONNECTIVITY_ID_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    BOOK_NAME_FIELD_NUMBER: builtins.int
    @property
    def pre_filter(self) -> global___PreFilter: ...
    message_timeout: builtins.int
    """Timeout to wait for messages after checkpoint. The message's timestamp will be used to compute the timeout"""

    timeout: builtins.int
    """Timeout for rule execution. Uses the real time to limit the execution of the rule"""

    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint:
        """Registered Checkpoint. If the chain_id is also set in the request the checkpoint will be ignored"""
        pass
    @property
    def chain_id(self) -> global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""
        pass
    @property
    def connectivity_id(self) -> th2_grpc_common.common_pb2.ConnectionID: ...
    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...
    description: typing.Text
    direction: th2_grpc_common.common_pb2.Direction.ValueType
    book_name: typing.Text
    def __init__(self,
        *,
        pre_filter: typing.Optional[global___PreFilter] = ...,
        message_timeout: builtins.int = ...,
        timeout: builtins.int = ...,
        checkpoint: typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        chain_id: typing.Optional[global___ChainID] = ...,
        connectivity_id: typing.Optional[th2_grpc_common.common_pb2.ConnectionID] = ...,
        parent_event_id: typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        description: typing.Text = ...,
        direction: th2_grpc_common.common_pb2.Direction.ValueType = ...,
        book_name: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","checkpoint",b"checkpoint","connectivity_id",b"connectivity_id","parent_event_id",b"parent_event_id","pre_filter",b"pre_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["book_name",b"book_name","chain_id",b"chain_id","checkpoint",b"checkpoint","connectivity_id",b"connectivity_id","description",b"description","direction",b"direction","message_timeout",b"message_timeout","parent_event_id",b"parent_event_id","pre_filter",b"pre_filter","timeout",b"timeout"]) -> None: ...
global___NoMessageCheckRequest = NoMessageCheckRequest

class NoMessageCheckResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...
    @property
    def chain_id(self) -> global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""
        pass
    def __init__(self,
        *,
        status: typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        chain_id: typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chain_id",b"chain_id","status",b"status"]) -> None: ...
global___NoMessageCheckResponse = NoMessageCheckResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_check1/check1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cth2_grpc_check1/check1.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cth2_grpc_common/common.proto\"K\n\x11\x43heckpointRequest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\"U\n\x12\x43heckpointResponse\x12\x1f\n\ncheckpoint\x18\x01 \x01(\x0b\x32\x0b.Checkpoint\x12\x1e\n\x06status\x18\x02 \x01(\x0b\x32\x0e.RequestStatus\"\x15\n\x07\x43hainID\x12\n\n\x02id\x18\x01 \x01(\t\"\xc0\x02\n\x10\x43heckRuleRequest\x12&\n\x0f\x63onnectivity_id\x18\x01 \x01(\x0b\x32\r.ConnectionID\x12\'\n\x0broot_filter\x18\n \x01(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\x0b \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12!\n\x0fparent_event_id\x18\x06 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x1d\n\tdirection\x18\x08 \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\t \x01(\x0b\x32\x08.ChainID\x12\x11\n\tbook_name\x18\x0c \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\"O\n\x11\x43heckRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\"\xb9\x03\n\x18\x43heckSequenceRuleRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x30\n\x14root_message_filters\x18\x0c \x03(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\r \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12&\n\x0f\x63onnectivity_id\x18\x05 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x63heck_order\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x1d\n\tdirection\x18\n \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\x0b \x01(\x0b\x32\x08.ChainID\x12\x31\n\rsilence_check\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tbook_name\x18\x0f \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x06\x10\x07\"W\n\x19\x43heckSequenceRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\"\xa0\x01\n\tPreFilter\x12&\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x16.PreFilter.FieldsEntry\x12(\n\x0fmetadata_filter\x18\x03 \x01(\x0b\x32\x0f.MetadataFilter\x1a;\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ValueFilter:\x02\x38\x01J\x04\x08\x01\x10\x02\"\xb0\x02\n\x15NoMessageCheckRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x17\n\x0fmessage_timeout\x18\x02 \x01(\x03\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x1f\n\ncheckpoint\x18\x04 \x01(\x0b\x32\x0b.Checkpoint\x12\x1a\n\x08\x63hain_id\x18\x05 \x01(\x0b\x32\x08.ChainID\x12&\n\x0f\x63onnectivity_id\x18\x06 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1d\n\tdirection\x18\t \x01(\x0e\x32\n.Direction\x12\x11\n\tbook_name\x18\n \x01(\t\"T\n\x16NoMessageCheckResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID2\xa2\x02\n\x06\x43heck1\x12=\n\x10\x63reateCheckpoint\x12\x12.CheckpointRequest\x1a\x13.CheckpointResponse\"\x00\x12:\n\x0fsubmitCheckRule\x12\x11.CheckRuleRequest\x1a\x12.CheckRuleResponse\"\x00\x12R\n\x17submitCheckSequenceRule\x12\x19.CheckSequenceRuleRequest\x1a\x1a.CheckSequenceRuleResponse\"\x00\x12I\n\x14submitNoMessageCheck\x12\x16.NoMessageCheckRequest\x1a\x17.NoMessageCheckResponse\"\x00\x42 \n\x1c\x63om.exactpro.th2.check1.grpcP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_check1.check1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.exactpro.th2.check1.grpcP\001'
  _PREFILTER_FIELDSENTRY._options = None
  _PREFILTER_FIELDSENTRY._serialized_options = b'8\001'
  _CHECKPOINTREQUEST._serialized_start=94
  _CHECKPOINTREQUEST._serialized_end=169
  _CHECKPOINTRESPONSE._serialized_start=171
  _CHECKPOINTRESPONSE._serialized_end=256
  _CHAINID._serialized_start=258
  _CHAINID._serialized_end=279
  _CHECKRULEREQUEST._serialized_start=282
  _CHECKRULEREQUEST._serialized_end=602
  _CHECKRULERESPONSE._serialized_start=604
  _CHECKRULERESPONSE._serialized_end=683
  _CHECKSEQUENCERULEREQUEST._serialized_start=686
  _CHECKSEQUENCERULEREQUEST._serialized_end=1127
  _CHECKSEQUENCERULERESPONSE._serialized_start=1129
  _CHECKSEQUENCERULERESPONSE._serialized_end=1216
  _PREFILTER._serialized_start=1219
  _PREFILTER._serialized_end=1379
  _PREFILTER_FIELDSENTRY._serialized_start=1314
  _PREFILTER_FIELDSENTRY._serialized_end=1373
  _NOMESSAGECHECKREQUEST._serialized_start=1382
  _NOMESSAGECHECKREQUEST._serialized_end=1686
  _NOMESSAGECHECKRESPONSE._serialized_start=1688
  _NOMESSAGECHECKRESPONSE._serialized_end=1772
  _CHECK1._serialized_start=1775
  _CHECK1._serialized_end=2065
# @@protoc_insertion_point(module_scope)
